================================================
``psyclone.psyad.transformations.adjoint_trans``
================================================

.. automodule:: psyclone.psyad.transformations.adjoint_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyad.transformations.adjoint_trans


Classes
=======

- :py:class:`AdjointTransformation`:
  An abstract class for Adjoint transformations. Requires a list of


.. autoclass:: AdjointTransformation
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: AdjointTransformation
      :parts: 1
